summaryrefslogtreecommitdiff
path: root/numpy/lib/function_base.py
diff options
context:
space:
mode:
authorTravis Oliphant <oliphant@enthought.com>2006-01-04 19:00:27 +0000
committerTravis Oliphant <oliphant@enthought.com>2006-01-04 19:00:27 +0000
commite706c7d92c4ee41e8e995fb3838bd0931b57efb5 (patch)
tree015a057d49422774e49ed211a37c14105d03a713 /numpy/lib/function_base.py
parentc14d4fe25cb5cd482369734dd487ac8f376851c9 (diff)
downloadnumpy-e706c7d92c4ee41e8e995fb3838bd0931b57efb5.tar.gz
Changed all references to scipy to numpy
Diffstat (limited to 'numpy/lib/function_base.py')
-rw-r--r--numpy/lib/function_base.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/numpy/lib/function_base.py b/numpy/lib/function_base.py
index 60e4b4be0..b7c8c04be 100644
--- a/numpy/lib/function_base.py
+++ b/numpy/lib/function_base.py
@@ -479,9 +479,9 @@ def trim_zeros(filt, trim='fb'):
""" Trim the leading and trailing zeros from a 1D array.
Example:
- >>> import scipy
+ >>> import numpy
>>> a = array((0, 0, 0, 1, 2, 3, 2, 1, 0))
- >>> scipy.trim_zeros(a)
+ >>> numpy.trim_zeros(a)
array([1, 2, 3, 2, 1])
"""
first = 0
@@ -583,10 +583,10 @@ class vectorize(object):
Description:
Define a vectorized function which takes nested sequence
objects or scipy arrays as inputs and returns a
scipy array as output, evaluating the function over successive
tuples of the input arrays like the python map function except it uses
the broadcasting rules of scipy.
Input:
@@ -768,10 +768,10 @@ def hamming(M):
def kaiser(M,beta):
"""kaiser(M, beta) returns a Kaiser window of length M with shape parameter
- beta. It depends on scipy.special (in full scipy) for the modified bessel
+ beta. It depends on numpy.special (in full numpy) for the modified bessel
function i0.
"""
- from scipy.special import i0
+ from numpy.special import i0
n = arange(0,M)
alpha = (M-1)/2.0
return i0(beta * sqrt(1-((n-alpha)/alpha)**2.0))/i0(beta)
@@ -583,10 +583,10 @@ class vectorize(object):
Description:
Define a vectorized function which takes nested sequence
- objects or scipy arrays as inputs and returns a
- scipy array as output, evaluating the function over successive
+ objects or numpy arrays as inputs and returns a
+ numpy array as output, evaluating the function over successive
tuples of the input arrays like the python map function except it uses
@@ -583,10 +583,10 @@ class vectorize(object):
tuples of the input arrays like the python map function except it uses
- the broadcasting rules of scipy.
+ the broadcasting rules of numpy.
Input: